pub fn align_schema_with_json_array(
schema: SchemaRef,
columns: &[ArrayRef],
) -> SchemaRefExpand description
Aligns JSON2 field types with their built arrays while preserving field and schema metadata.
pub fn align_schema_with_json_array(
schema: SchemaRef,
columns: &[ArrayRef],
) -> SchemaRefAligns JSON2 field types with their built arrays while preserving field and schema metadata.